import warnings
warnings.warn(
    "aegis-pay has been renamed to pop-pay. "
    "Please update: pip install pop-pay  |  https://github.com/TPEmist/Point-One-Percent",
    DeprecationWarning,
    stacklevel=2,
)
